@@ -1,7 +1,7 @@
 package App::lcpan::Cmd::author_dists;
 
-our $DATE = '2016-02-07'; # DATE
-our $VERSION = '0.66'; # VERSION
+our $DATE = '2016-02-11'; # DATE
+our $VERSION = '0.67'; # VERSION
 
 use 5.010;
 use strict;
@@ -18,9 +18,7 @@ $SPEC{'handle_cmd'} = {
         %App::lcpan::common_args,
         %App::lcpan::author_args,
         %App::lcpan::flatest_args,
-        detail => {
-            schema => 'bool',
-        },
+        %App::lcpan::detail_args,
     },
 };
 sub handle_cmd {
@@ -44,7 +42,7 @@ App::lcpan::Cmd::author_dists - List distributions of an author
 
 =head1 VERSION
 
-This document describes version 0.66 of App::lcpan::Cmd::author_dists (from Perl distribution App-lcpan), released on 2016-02-07.
+This document describes version 0.67 of App::lcpan::Cmd::author_dists (from Perl distribution App-lcpan), released on 2016-02-11.
 
 =head1 FUNCTIONS
 
