@@ -1,7 +1,7 @@
 package App::lcpan::Cmd::author_mods;
 
-our $DATE = '2016-02-07'; # DATE
-our $VERSION = '0.66'; # VERSION
+our $DATE = '2016-02-11'; # DATE
+our $VERSION = '0.67'; # VERSION
 
 use 5.010;
 use strict;
@@ -17,9 +17,7 @@ $SPEC{'handle_cmd'} = {
     args => {
         %App::lcpan::common_args,
         %App::lcpan::author_args,
-        detail => {
-            schema => 'bool',
-        },
+        %App::lcpan::detail_args,
     },
     tags => [],
 };
@@ -44,7 +42,7 @@ App::lcpan::Cmd::author_mods - List modules of an author
 
 =head1 VERSION
 
-This document describes version 0.66 of App::lcpan::Cmd::author_mods (from Perl distribution App-lcpan), released on 2016-02-07.
+This document describes version 0.67 of App::lcpan::Cmd::author_mods (from Perl distribution App-lcpan), released on 2016-02-11.
 
 =head1 FUNCTIONS
 
