@@ -1,7 +1,7 @@
 package App::lcpan::Cmd::author_rels;
 
-our $DATE = '2016-02-07'; # DATE
-our $VERSION = '0.66'; # VERSION
+our $DATE = '2016-02-11'; # DATE
+our $VERSION = '0.67'; # VERSION
 
 use 5.010;
 use strict;
@@ -19,9 +19,7 @@ $SPEC{'handle_cmd'} = {
         %App::lcpan::author_args,
         %App::lcpan::flatest_args,
         %App::lcpan::full_path_args,
-        detail => {
-            schema => 'bool',
-        },
+        %App::lcpan::detail_args,
     },
 };
 sub handle_cmd {
@@ -45,7 +43,7 @@ App::lcpan::Cmd::author_rels - List releases of an author
 
 =head1 VERSION
 
-This document describes version 0.66 of App::lcpan::Cmd::author_rels (from Perl distribution App-lcpan), released on 2016-02-07.
+This document describes version 0.67 of App::lcpan::Cmd::author_rels (from Perl distribution App-lcpan), released on 2016-02-11.
 
 =head1 FUNCTIONS
 
