@@ -1,7 +1,7 @@
 package App::lcpan::Cmd::distmods;
 
-our $DATE = '2016-02-07'; # DATE
-our $VERSION = '0.66'; # VERSION
+our $DATE = '2016-02-11'; # DATE
+our $VERSION = '0.67'; # VERSION
 
 use 5.010;
 use strict;
@@ -17,9 +17,7 @@ $SPEC{'handle_cmd'} = {
     args => {
         %App::lcpan::common_args,
         %App::lcpan::dist_args,
-        detail => {
-            schema => 'bool',
-        },
+        %App::lcpan::detail_args,
     },
 };
 sub handle_cmd {
@@ -33,7 +31,8 @@ sub handle_cmd {
 
     my $sth = $dbh->prepare("SELECT
   module.name name,
-  module.version version
+  module.version version,
+  module.abstract abstract
 FROM module
 LEFT JOIN file ON module.file_id=file.id
 LEFT JOIN dist ON file.id=dist.file_id
@@ -45,7 +44,7 @@ ORDER BY name DESC");
         push @res, $detail ? $row : $row->{name};
     }
     my $resmeta = {};
-    $resmeta->{'table.fields'} = [qw/name version/]
+    $resmeta->{'table.fields'} = [qw/name version abstract/]
         if $detail;
     [200, "OK", \@res, $resmeta];
 }
@@ -65,7 +64,7 @@ App::lcpan::Cmd::distmods - List modules in a distribution
 
 =head1 VERSION
 
-This document describes version 0.66 of App::lcpan::Cmd::distmods (from Perl distribution App-lcpan), released on 2016-02-07.
+This document describes version 0.67 of App::lcpan::Cmd::distmods (from Perl distribution App-lcpan), released on 2016-02-11.
 
 =head1 FUNCTIONS
 
