@@ -1,7 +1,7 @@
 package App::lcpan::Cmd::mods_from_same_dist;
 
-our $DATE = '2016-02-07'; # DATE
-our $VERSION = '0.66'; # VERSION
+our $DATE = '2016-02-11'; # DATE
+our $VERSION = '0.67'; # VERSION
 
 use 5.010;
 use strict;
@@ -18,9 +18,7 @@ $SPEC{'handle_cmd'} = {
         %App::lcpan::common_args,
         %App::lcpan::mods_args,
         %App::lcpan::flatest_args,
-        detail => {
-            schema => 'bool',
-        },
+        %App::lcpan::detail_args,
     },
 };
 sub handle_cmd {
@@ -42,6 +40,7 @@ sub handle_cmd {
     my $sth = $dbh->prepare("SELECT
   module.name name,
   module.version version,
+  module.abstract abstract,
   dist.name dist,
   dist.version dist_version
 FROM module
@@ -54,7 +53,7 @@ ORDER BY name DESC");
         push @res, $detail ? $row : $row->{name};
     }
     my $resmeta = {};
-    $resmeta->{'table.fields'} = [qw/name version dist dist_version/]
+    $resmeta->{'table.fields'} = [qw/name version abstract dist dist_version/]
         if $detail;
     [200, "OK", \@res, $resmeta];
 }
@@ -74,7 +73,7 @@ App::lcpan::Cmd::mods_from_same_dist - Given a module, list all modules in the s
 
 =head1 VERSION
 
-This document describes version 0.66 of App::lcpan::Cmd::mods_from_same_dist (from Perl distribution App-lcpan), released on 2016-02-07.
+This document describes version 0.67 of App::lcpan::Cmd::mods_from_same_dist (from Perl distribution App-lcpan), released on 2016-02-11.
 
 =head1 FUNCTIONS
 
